elastic-apm -- Elastic APM agent for Python
===========================================

.. image:: https://api.travis-ci.org/elastic/apm-agent-python.svg?branch=master
    :target: https://travis-ci.org/elastic/apm-agent-python
    :alt: Build Status
    
.. image:: https://img.shields.io/pypi/v/elastic-apm.svg?style=flat
    :target: https://pypi.python.org/pypi/elastic-apm/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/elastic-apm.svg?style=flat
    :target: https://pypi.python.org/pypi/elastic-apm/
    :alt: Supported Python versions


This is the official Python module for Elastic APM.

It provides full out-of-the-box support for many of the popular frameworks,
including Django, and Flask. Elastic APM also includes drop-in support for any
WSGI-compatible web application.

Your application doesn't live on the web? No problem! Elastic APM is easy to use in
any Python application.


License
-------

BSD-3-Clause


Made with ♥️ and ☕️ by Elastic, Inc. and our community.
